#
# Copyright 2007 Fedora Unity
#
# Jonathan Steffan <jon a fedoraunity.org>
# Jeroen van Meeuwen <kanarip a fedoraunity.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 only
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

import os
import revisor
import urlgrabber
import urlparse

def get_file(url, working_directory = "/var/tmp"):
    """Gets a file from url and returns the file name (full path)"""

    # Check if it isn't a file already
    if os.path.isfile(url): return url

    # Otherwise it might be an actual url
    file_basename = os.path.basename(urlparse.urlparse(url).path)
    file_name = os.path.join(working_directory, file_basename)

    if not check_file(file_name, destroy = True):
        # File does not exist or wasn't valid. Download the file.
        download_file(url, file_name)
    else:
        # There should be no else to this one
        pass

    return file_name

def download_file(url, file_name, title=None):
    urlgrabber.urlgrab(url, file_name, copy_local=1)

def check_file(file_name, checksum = None, destroy = False):
    """
    Checks if a file exists. Basically returns True if the file exists, unless the
    checksum doesn't check out or destroy has been set to True.

    If the file exists:
        Checksum:
            If specified, run the checksum and return:
                - True if the checksum checks out.
                - False if it doesn't and destroy the file.
            If not specified:
                - Continue
        Destroy:
            If True:
                - Destroy the file and return False
            else:
                - Return True
    else:
        - return False

    """
    if os.access(file_name, os.R_OK):
        if not checksum == None:
            if file_checksum(file_name, checksum):
                return True
            else:
                return False
        elif destroy:
            os.remove(file_name)
            return False
        else:
            return True
    else:
        return False

